@@ -36,7 +36,29 @@ class Analysis:
         })
 
     def auto_select(self, initial_model, criterion, method, alpha=None, select_by_degree=False, **kwargs):
-        """ Performs an auto-selection on an initial model. """
+        """ Performs an auto-selection on an initial model.
+
+        :param str initial_model: A model to auto-select a subset of terms from.
+        :param str criterion: The criterion used to evaluate each sub-model.
+                              Valid options are "AICc", "BIC", "pValues",
+                              or "AdjRSquared" (case-insensitive).
+        :param str method: The method used to select sub-models. Valid options
+                           are "Forward", "Backward", "Stepwise", and
+                           "AllHierarchical" (case-insensitive).
+        :param float alpha: This is the alpha used to either include or exclude
+                            terms when using the "pValues" criterion. You can
+                            also pass `alpha_in` and/or `alpha_out` to set
+                            those values separately (setting both only has an
+                            effect when using the "Stepwise" method).
+        :param bool select_by_degree: Restricts the sub-model comparisons to
+                                      lower order terms before considering
+                                      higher order terms.
+
+        :Example:
+            >>> result_model = analysis.auto_select('A+B+C+AB+BC+ABC', 'BICc', 'Backward')
+            >>> print(result_model)
+            >>> "A+B+AB"
+        """
         payload = {
             "method": "POST",
             "uri": "analysis/" + self.name + "/autoselect",
