@@ -77,6 +77,32 @@ class SEClient:
             "message": message,
         })
 
+    def set_preference(self, key, value, area = ""):
+        """Sets a preference.
+
+        :param str key: The preference key. This can be found in the Stat-Ease 360 preference dialog.
+        :param str value: The value to assign to the preference.
+        """
+        self.send_payload({
+            "method": "POST",
+            "uri": "preference",
+            "key": key,
+            "value": value,
+            "area": area,
+        })
+
+    def get_preference(self, key):
+        """Retrieves the current value of a preference.
+
+        :param str key: The preference key. This can be found in the Stat-Ease 360 preference dialog.
+        """
+        result = self.send_payload({
+            "method": "GET",
+            "uri": "preference",
+            "key": key,
+        })
+        return result['payload']['preference']
+
     def go_to_node(self, node, analysis_name):
         self.send_payload({
             "method": "POST",
@@ -92,6 +118,13 @@ class SEClient:
             "path": path,
         })
 
+    def save_design(self, path = ""):
+        self.send_payload({
+            "method": "POST",
+            "uri": "save",
+            "path": path,
+        })
+
     def list_analyses(self):
         result = self.send_payload({
             "method": "GET",
@@ -107,6 +140,12 @@ class SEClient:
         return Optimizer(self)
 
     def create_analysis(self, response_name, analysis_name, transform="No Transform"):
+        """Creates an analysis for a response.
+
+        :param str response_name: The name of the response to analyze.
+        :param str analysis_name: The desired name for this analysis.
+        :param str transform: The transform to apply to the response for this analysis. The default is "No Transform".
+        """
 
         reply = self.send_payload({
             "method": "POST",
@@ -118,6 +157,35 @@ class SEClient:
 
         return Analysis(self, analysis_name)
 
+    def delete_analysis(self, analysis_name):
+        """Deletes an analysis.
+
+        :param str analysis_name: The name of the analysis to delete.
+        """
+        self.send_payload({
+            "method": "DELETE",
+            "uri": "analysis/delete",
+            "analysis_name": analysis_name
+        })
+
+    def create_response(self, response_name, response_units="", response_format="General"):
+        """Creates a response.
+
+        :param str response_name: The desired name of the response.
+        :param str response_units: The response units.
+        :param str response_format: The format of the response values in the user interface. The default is "General".
+        """
+
+        reply = self.send_payload({
+            "method": "POST",
+            "uri": "design/response/create",
+            "response_name": response_name,
+            "response_units": response_units,
+            "response_format": response_format
+        })
+        
+        return Response(self, response_name)
+
     def list_responses(self):
         """Returns a list of all response names in the current design.
 
@@ -152,6 +220,38 @@ class SEClient:
         """
         return Response(self, name)
 
+    def delete_response(self, response_name):
+        """Deletes a response.
+
+        :param str response_name: The name of the response to delete.
+        """
+        self.send_payload({
+            "method": "DELETE",
+            "uri": "design/response/delete",
+            "response_name": response_name
+        })
+
+    def create_factor(self, factor_name, factor_levels = [-1,1], factor_type = "numeric", categoric_type="nominal"):
+        """Creates a factor.
+
+        :param str factor_name: The name of the factor.
+        :param list factor_levels: The actual levels of the factor. For continuous factors this should simply be [low, high].
+                For categoric or discrete factors this should be a list of all valid factor levels. The default is [-1, 1].
+        :param str factor_type: The type of the factor. The default is "numeric".
+        :param str categoric_type: If the factor type is "categoric", this will set type of categoric factor (e.g. nominal or ordinal). The default is "nominal".
+        """
+
+        reply = self.send_payload({
+            "method": "POST",
+            "uri": "design/factor/create",
+            "factor_name": factor_name,
+            "factor_levels": factor_levels,
+            "factor_type": factor_type,
+            "categoric_type": categoric_type
+        })
+
+        return Factor(self, factor_name)
+
     def list_factors(self):
         """Returns a list of all factor names in the current design.
 
@@ -186,6 +286,17 @@ class SEClient:
         """
         return Factor(self, name)
 
+    def delete_factor(self, factor_name):
+        """Deletes a factor.
+
+        :param str factor_name: The name of the factor to delete.
+        """
+        self.send_payload({
+            "method": "DELETE",
+            "uri": "design/factor/delete",
+            "factor_name": factor_name
+        })
+
     def get_design_model(self):
         result = self.send_payload({
             "method": "GET",
